#
# spec file for package kubearmor-client
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kubearmor-client
Version:        1.3.3
Release:        1.1
Summary:        KubeArmor cli tool aka kArmor
License:        Apache-2.0
URL:            https://github.com/kubearmor/kubearmor-client
Source:         kubearmor-client-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.22
BuildRequires:  zsh

%description
karmor is a client tool to help manage KubeArmor, which is a Cloud-native
Runtime Security Enforcement System. Workload hardening and implementing
least-permissive policies made easy.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%setup -q
%setup -q -T -D -a 1

%build
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")

go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/kubearmor/kubearmor-client/selfupdate.GitCommit=${COMMIT_HASH} \
   -X github.com/kubearmor/kubearmor-client/selfupdate.GitSummary=v%{version} \
   -X github.com/kubearmor/kubearmor-client/selfupdate.GitBranch=main  \
   -X github.com/kubearmor/kubearmor-client/selfupdate.GitState=clean  \
   -X github.com/kubearmor/kubearmor-client/selfupdate.BuildDate=${BUILD_DATE}" \
   -o bin/kubearmor-client .

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"
cd "%{buildroot}/%{_bindir}/"
ln -s %{name} karmor

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
%{_bindir}/karmor

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Thu Feb 27 2025 opensuse_buildservice@ojkastl.de
- Update to version 1.3.3:
  * annotate existing functionality for karmor install
* Mon Feb 24 2025 opensuse_buildservice@ojkastl.de
- Update to version 1.3.2:
  * fix os-release
* Fri Feb 21 2025 opensuse_buildservice@ojkastl.de
- Update to version 1.3.1:
  * upgrade go dependencies
  * remove deprecated package vm
  * Karmor support for windows and removal of cilium (#471)
  * fix: recommend
* Fri Dec 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.3.0:
  * fix(uninstall):remove kubearmor annotations from kubernetes
    resources (#440)
  * fixing snyk
  * enabling alert throttling by default
  * fix gosec
  * fix(sysdump): ensure AppArmor tar is gzipped in sysdump
  * probe added to sysdump
  * chore(logs): add output format option to `logs` command (#447)
  * Update label and add debug print statement for KubeArmor pods
  * Updated the static policies under res/out and updated kubearmor
    dependency
* Mon Jun 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.3:
  * use stable operator
* Thu May 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.2:
  * fix(probe): directly ftech kubearmor pods from k8s api instead
    of listing nodes
  * Feat: added postUpdate option in Renovate for go tidy (#429)
  * use go1.21
  * nitfix: keep command in code block
  * Remove usage of sudo to install kubearmor-client
  * fix(deps): update module helm.sh/helm/v3 to v3.14.3
  * chore(deps): update helm/kind-action action to v1.9.0
  * Update: Scorecard to latest version
  * fix(deps): update module github.com/docker/docker to
    v25.0.5+incompatible [security]
  * chore(deps): update dependency jquery to v3.7.1
  * chore(deps): update actions/checkout action to v3.6.0
* Thu Apr 18 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- do not strip aka remove -s -w ldflags
* Sat Mar 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.1:
  * fixed stdout issue with log message
  * update tls config
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- BuildRequire go1.22 following upstream
- Update to version 1.2.0:
  * add mtls support
  * chore: use go toolchain 1.22.1
  * chore(ci): upgrade codeqql to v3
  * Added operator CR updation functionality
  * linted readme
  * Enabled operator installation for karmor
  * Fixed the probe panic issue
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.1.1:
  * fix bug & add flags
  * feat(deps):Updated codeQL to v2
  * update kubearmor protobuf
  * updated karmor install with relay's sa and rbac policies
* Thu Feb  8 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.1.0:
  * enable custom registry
* Mon Dec  4 2023 kastl@b1-systems.de
- Update to version 1.0.0:
  * updated kubearmor dependencies
  * ignore cluster access with save flag
* Fri Nov 17 2023 kastl@b1-systems.de
- Update to version 0.14.3:
  * update go version to v1.21
  * fix `karmor uninstall`
  * fixing the issue about progress bar
  * default read permissions for all workflows
- BuildRequire go1.21
* Wed Oct 25 2023 kastl@b1-systems.de
- Update to version 0.14.2:
  * fix(deps): update github.com/kubearmor/kubearmor/deployments
    digest to 15ad34e
  * feat: allow karmor probe to show policies applied in systemd
    mode
  * remove summary, discover as they depend on an external tool
  * add govulncheck install check
  * add govulncheck scan to Makefile
* Wed Oct 11 2023 Johannes Kastl <kastl@b1-systems.de>
- upstream fixed the missing third digit in the version, code stays
  the same (tag 0.14 has the same code as 0.14.1)
* Tue Oct 10 2023 kastl@b1-systems.de
- Update to version 0.14:
  * feat(ns): update default namespace to "kubearmor" (#361)
  * feat: Add support for k0s
  * feat: Enhanced handling of policy addition and deletion events
  * Add license scan report and status
  * handling comments and empty objects in policy
  * migrate Userhome func to common
  * refractoring recommend cli
* Mon Oct  9 2023 Johannes Kastl <kastl@b1-systems.de>
- new package kubearmor-client: CLI for the Kubernetes KubeArmor
  Cloud-native Runtime Security Enforcement System
